Package: ManlyMix
Version: 0.1.15.1
Date: 2023-04-27
Title: Manly Mixture Modeling and Model-Based Clustering
Authors@R: c(person("Xuwen", "Zhu", role = c("aut", "cre"),
                    email = "xzhu20@cba.ua.edu"),
             person("Volodymyr", "Melnykov", role = "aut"),
             person("Michael", "Hutt", role = c("ctb", "cph"),
                    comment = "NM optimization in c"),
             person("Stephen", "Moshier", role = c("ctb", "cph"),
                    comment = "eigen calculations in c"),
             person("Rouben", "Rostamian", role = c("ctb", "cph"),
                    comment = "memory allocation in c"))
Depends: R (>= 3.0.0)
LazyLoad: yes
LazyData: no
Description: The utility of this package includes finite mixture modeling and model-based clustering through Manly mixture models by Zhu and Melnykov (2016) <DOI:10.1016/j.csda.2016.01.015>. It also provides capabilities for forward and backward model selection procedures.  
License: GPL (>= 2)
Packaged: 2024-09-18 10:05:13 UTC; ripley
Author: Xuwen Zhu [aut, cre],
  Volodymyr Melnykov [aut],
  Michael Hutt [ctb, cph] (NM optimization in c),
  Stephen Moshier [ctb, cph] (eigen calculations in c),
  Rouben Rostamian [ctb, cph] (memory allocation in c)
Maintainer: Xuwen Zhu <xzhu20@cba.ua.edu>
NeedsCompilation: yes
Repository: CRAN
Date/Publication: 2024-09-23 11:15:38 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 21:33:29 UTC; unix
Archs: ManlyMix.so.dSYM
