useDynLib(ManlyMix, .registration = TRUE)
importFrom("graphics", "contour", "points", "hist", "box")
importFrom("stats", "rmultinom", "rnorm", "hclust", "kmeans", "cutree", "dist", "qnorm")
importFrom("utils", "combn")
export(Manly.EM)
export(Manly.select)
export(Manly.Kmeans)
export(Manly.plot)
export(Manly.var)
export(Manly.sim)
export(Manly.overlap)
export(ClassAgree)
export(Manly.model)